@@ -1,6 +1,6 @@
 import unittest
 
-from .gray_code import gen_gray_codes, gray_code_to_tc, tc_to_gray_code
+from graycode import gen_gray_codes, gray_code_to_tc, tc_to_gray_code
 
 
 class GrayCodeTestCase(unittest.TestCase):
